# haplohub
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.0.0
- Generator version: 7.11.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonPydanticV1ClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import haplohub
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import haplohub
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import haplohub
from haplohub.rest import ApiException
from pprint import pprint

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: 
configuration = haplohub.Configuration(
    access_token=os.environ["API_KEY"]
)


# Enter a context with an instance of the API client
with haplohub.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = haplohub.MetadataApi(api_client)

    try:
        # Each accession is a string of DNA that is used as a reference. These are defined by https://www.ncbi.nlm.nih.gov/grc/human/data?asm=GRCh38
        api_response = api_instance.accession()
        print("The response of MetadataApi->accession:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling MetadataApi->accession: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*MetadataApi* | [**accession**](docs/MetadataApi.md#accession) | **GET** /api/v1/metadata/ | Each accession is a string of DNA that is used as a reference. These are defined by https://www.ncbi.nlm.nih.gov/grc/human/data?asm&#x3D;GRCh38
*PredictionsApi* | [**get_prediction**](docs/PredictionsApi.md#get_prediction) | **GET** /api/v1/prediction/{prediction_id}/ | Get prediction
*PredictionsApi* | [**get_prediction_results**](docs/PredictionsApi.md#get_prediction_results) | **GET** /api/v1/prediction/{prediction_id}/results/ | Get prediction results
*PredictionsApi* | [**list_predictions**](docs/PredictionsApi.md#list_predictions) | **GET** /api/v1/prediction/ | List predictions
*PredictionsApi* | [**run_prediction**](docs/PredictionsApi.md#run_prediction) | **POST** /api/v1/prediction/ | Run prediction
*SampleApi* | [**hgvs_dosage**](docs/SampleApi.md#hgvs_dosage) | **GET** /api/v1/sample/ | Fetch the dosage of a given allele for a sample based on the hgvs nomenclature. For example &#39;NC_000001.11:g.11794419T&gt;G&#39;
*DefaultApi* | [**status**](docs/DefaultApi.md#status) | **GET** /api/v1/status/ | Status


## Documentation For Models

 - [AccessionSchema](docs/AccessionSchema.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [ErrorSchema](docs/ErrorSchema.md)
 - [GetHgvsResponse](docs/GetHgvsResponse.md)
 - [GetPredictionResponse](docs/GetPredictionResponse.md)
 - [GetPredictionResultsResponse](docs/GetPredictionResultsResponse.md)
 - [HgvsDosageSchema](docs/HgvsDosageSchema.md)
 - [PaginatedResponseAccessionSchema](docs/PaginatedResponseAccessionSchema.md)
 - [PaginatedResponsePredictionSchema](docs/PaginatedResponsePredictionSchema.md)
 - [PredictionResultsSchema](docs/PredictionResultsSchema.md)
 - [PredictionSchema](docs/PredictionSchema.md)
 - [PredictionStatus](docs/PredictionStatus.md)
 - [Response](docs/Response.md)
 - [Response1](docs/Response1.md)
 - [Response2](docs/Response2.md)
 - [Response3](docs/Response3.md)
 - [ResponseStatus](docs/ResponseStatus.md)
 - [RunPredictionRequest](docs/RunPredictionRequest.md)
 - [RunPredictionResponse](docs/RunPredictionResponse.md)
 - [SuccessResponse](docs/SuccessResponse.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ApiAuthBearer"></a>
### ApiAuthBearer

- **Type**: Bearer authentication


## Author




